Struct vulkanalia_sys::Extension
source · [−]pub struct Extension {
pub name: ExtensionName,
pub number: i32,
pub type_: &'static str,
pub author: &'static str,
pub contact: &'static str,
pub platform: Option<&'static str>,
pub required_extensions: Option<&'static [ExtensionName]>,
pub required_version: Option<&'static str>,
pub deprecated_by: Option<&'static str>,
pub obsoleted_by: Option<&'static str>,
pub promoted_to: Option<&'static str>,
}Expand description
A collection of metadata for a Vulkan extension.
Fields
name: ExtensionNameThe name of the extension.
number: i32The unique number assigned to the extension.
type_: &'static strThe type of the extension (device or instance).
The author of the extension (e.g., KHR).
contact: &'static strThe primary contact(s) for the extension.
platform: Option<&'static str>The platform the extension applies to (e.g., wayland or win32).
required_extensions: Option<&'static [ExtensionName]>The other extensions required by the extension.
required_version: Option<&'static str>The Vulkan version required by the extension (e.g., 1.1).
deprecated_by: Option<&'static str>The Vulkan extension or version that deprecated the extension (e.g., VK_VERSION_1_1).
obsoleted_by: Option<&'static str>The Vulkan extension or version that obsoleted the extension (e.g., VK_VERSION_1_1).
promoted_to: Option<&'static str>The Vulkan version the extension was promoted to core in (e.g., VK_VERSION_1_1).